ParentInfo class

The results of parents info.

Constructors

ParentInfo(Map<String, dynamic> nativeParentInfo)

Properties

firstName StringResult?
The first name of one of the document owner's parents.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
lastName StringResult?
The last name of one of the document owner's parents.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited